==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorLoginDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorLoginDB::BEGIN{package NXTwoFactorLoginDB;no warnings;require 
Error;do{"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub 
NXTwoFactorLoginDB::savePublicKey{package NXTwoFactorLoginDB;no warnings;(my $user
=main::urlencode (shift (@_)));(my $key=main::urlencode (shift (@_)));if (($user
 eq (""))){Logger::warning (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x74\x68\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x2e"
);return ((0x0044+ 8176-0x2034));}if (($key eq (""))){Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x65\x6d\x70\x74\x79\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x27"
.$user)."\x27\x2e"));return ((0x1a91+ 808-0x1db9));}__lock ();(my $file=
NXPaths::getTwoFactorPublicKeys ());(my $openMode=(($NXBits::O_CREAT+
$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $FD=main::nxopen ($file,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($FD)))){(my $error=
libnxh::NXGetError ());(my $errorName=libnxh::NXGetErrorName ());(my $errorString
=libnxh::NXGetErrorString ());if ((not (defined ($FD)))){Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x06bf+ 4523-0x186a));}}(my $data=((($user."\x20").$key)."\x0a"));if ((
main::nxwrite ($FD,$data)==(-(0x1537+ 2037-0x1d2b)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($FD);Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x0a9c+ 1938-0x122e));}main::nxclose ($FD);__unlock ();return (
(0x135d+ 458-0x1526));}sub NXTwoFactorLoginDB::getPublicKeys{package 
NXTwoFactorLoginDB;no warnings;(my $user=shift (@_));(my (@keys)=
getAllPublicKeys ());(my (@userKeys)=());for ((my $i=(0x0fc2+ 4359-0x20c9));($i<
@keys);($i=($i+(0x03d9+ 4813-0x16a4)))){if (($user eq @keys[$i])){push (
@userKeys,$keys[$i+(0x0819+ 2391-0x116f)]);}}return (@userKeys);}sub 
NXTwoFactorLoginDB::getAllPublicKeys{package NXTwoFactorLoginDB;no warnings;(my $file
=NXPaths::getTwoFactorPublicKeys ());unless (Common::NXFile::isExists ($file)){
Logger::debug (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return (());}__lockShared ();(my $fileHandle=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($fileHandle)){(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::debug ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return (());}(my (@content)=());while (
main::nxreadLine ($fileHandle,(\$_))){chomp ($_);(my ($user,$key)=split ( / / ,
$_,(0x080a+ 1071-0x0c36)));($user=main::urldecode ($user));($key=main::urldecode
 ($key));Logger::debug3 (((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x20\x27"
.$user)."\x27\x20\x6b\x65\x79\x20\x27").$key)."\x27\x2e"));push (@content,$user,
$key);}main::nxclose ($fileHandle);__unlock ();return (@content);}sub 
NXTwoFactorLoginDB::removeUserKeys{package NXTwoFactorLoginDB;no warnings;(my $username
=shift (@_));(my $file=NXPaths::getTwoFactorPublicKeys ());(my $tempFile=(($file
."\x2e\x74\x6d\x70\x2e").$ $));
 unless (Common::NXFile::isExists ($file)){
Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return ((0x0356+ 6484-0x1caa));}__lock ();(my $FD=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($FD)){(my $errorNumber=libnxh::NXGetError 
());(my $errorString=libnxh::NXGetErrorString ());Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x087c+ 5814-0x1f32));}if (
Common::NXFile::isExists ($tempFile)){unlink ($tempFile);}(my $openMode=((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $tempFD=main::nxopen
 ($tempFile,$openMode,$NXBits::UserReadWrite));unless (defined ($tempFD)){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$tempFile)."\x27\x20\x66\x6f\x72\x20\x77\x72\x69\x74\x65\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x0b4b+ 5394-0x205d));}&try (sub{
while (main::nxreadLine ($FD,(\$_))){(my $line=$_);chomp ($line);(my ($keyUser,
$key)=split ( / / ,$line,(0x013d+ 5769-0x17c3)));($keyUser=main::urldecode (
$keyUser));if (($keyUser eq $username)){($flag_del=(0x1241+ 2747-0x1cfb));}else{
Common::NXCore::nxwriteOrThrowException ($tempFD,$_);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tempFD);main::nxclose ($FD);__unlock ();
Logger::error (((
"\x55\x6e\x65\x78\x70\x65\x63\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x77\x68\x69\x6c\x65\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x73\x61\x76\x65\x64\x20\x75\x73\x65\x72\x20\x74\x77\x6f\x20\x66\x61\x63\x74\x6f\x72\x20\x6b\x65\x79\x2e\x20"
.$error)."\x2e"));return ((0x032c+ 7880-0x21f4));}));main::nxclose ($tempFD);
main::nxclose ($FD);if ((not (rename ($tempFile,$file)))){__unlock ();
Logger::error ((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempFile)."\x27\x20\x74\x6f\x20\x27").$file)."\x27\x2e\x20").$!));return (
(0x00a3+ 2043-0x089e));}(my ($errorName),$errorCode);if ((
Common::NXFile::setOwnerShipAndPermissionsForNX ($file,(\$errorName),(
\$errorCode))==(-(0x028d+ 3029-0x0e61)))){__unlock ();Logger::error ((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x74\x20\x6f\x77\x6e\x65\x72\x73\x68\x69\x70\x20\x27\x6e\x78\x27\x20\x6f\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x6e\x78\x2e\x20").
$errorName));return ((0x10cc+ 4653-0x22f9));}__unlock ();return ($flag_del);}
package NXTwoFactorLoginDB;no warnings;my ($lockFD);sub __lock{(my $lockMode=(
shift (@_)||$NXBits::LOCK_EX));(my $lockFile=(NXPaths::getTwoFactorPublicKeys ()
."\x2e\x6c\x6f\x63\x6b"));(my $openMode=(($NXBits::O_CREAT+$NXBits::O_WRONLY)+
$NXBits::O_APPEND));($lockFD=main::nxopen ($lockFile,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($lockFD)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$lockFile)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));return ((0x14b4+ 4017-0x2465));}
main::nxflock ($lockFD,$lockMode);}sub __lockShared{return (__lock (
$NXBits::LOCK_SH));}sub __unlock{if (defined ($lockFD)){main::nxclose ($lockFD);
}($lockFD=undef);}return ((0x089d+ 2882-0x13de));

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorLoginDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorLoginDB::BEGIN{package NXTwoFactorLoginDB;no warnings;require 
Error;do{"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub 
NXTwoFactorLoginDB::savePublicKey{package NXTwoFactorLoginDB;no warnings;(my $user
=main::urlencode (shift (@_)));(my $key=main::urlencode (shift (@_)));if (($user
 eq (""))){Logger::warning (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x74\x68\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x2e"
);return ((0x15db+ 3582-0x23d9));}if (($key eq (""))){Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x61\x76\x65\x20\x65\x6d\x70\x74\x79\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x27"
.$user)."\x27\x2e"));return ((0x09fb+ 951-0x0db2));}__lock ();(my $file=
NXPaths::getTwoFactorPublicKeys ());(my $openMode=(($NXBits::O_CREAT+
$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $FD=main::nxopen ($file,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($FD)))){(my $error=
libnxh::NXGetError ());(my $errorName=libnxh::NXGetErrorName ());(my $errorString
=libnxh::NXGetErrorString ());if ((not (defined ($FD)))){Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x04b2+ 725-0x0787));}}(my $data=((($user."\x20").$key)."\x0a"));if ((
main::nxwrite ($FD,$data)==(-(0x08e6+ 3716-0x1769)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($FD);Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));__unlock ();return (
(0x032d+ 2034-0x0b1f));}main::nxclose ($FD);__unlock ();return (
(0x0cb4+ 1777-0x13a4));}sub NXTwoFactorLoginDB::getPublicKeys{package 
NXTwoFactorLoginDB;no warnings;(my $user=shift (@_));(my (@keys)=
getAllPublicKeys ());(my (@userKeys)=());for ((my $i=(0x18e2+ 2502-0x22a8));($i<
@keys);($i=($i+(0x2023+ 1301-0x2536)))){if (($user eq @keys[$i])){push (
@userKeys,$keys[$i+(0x054a+ 8388-0x260d)]);}}return (@userKeys);}sub 
NXTwoFactorLoginDB::getAllPublicKeys{package NXTwoFactorLoginDB;no warnings;(my $file
=NXPaths::getTwoFactorPublicKeys ());unless (Common::NXFile::isExists ($file)){
Logger::debug (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return (());}__lockShared ();(my $fileHandle=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($fileHandle)){(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::debug ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return (());}(my (@content)=());while (
main::nxreadLine ($fileHandle,(\$_))){chomp ($_);(my ($user,$key)=split ( / / ,
$_,(0x1469+  54-0x149c)));($user=main::urldecode ($user));($key=main::urldecode 
($key));Logger::debug3 (((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x55\x73\x65\x72\x20\x27"
.$user)."\x27\x20\x6b\x65\x79\x20\x27").$key)."\x27\x2e"));push (@content,$user,
$key);}main::nxclose ($fileHandle);__unlock ();return (@content);}sub 
NXTwoFactorLoginDB::removeUserKeys{package NXTwoFactorLoginDB;no warnings;(my $username
=shift (@_));(my $file=NXPaths::getTwoFactorPublicKeys ());(my $tempFile=(($file
."\x2e\x74\x6d\x70\x2e").$ $));
 unless (Common::NXFile::isExists ($file)){
Logger::warning (((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x65\x78\x69\x73\x74\x2e"))
;return ((0x035d+ 5467-0x18b8));}__lock ();(my $FD=main::nxopen ($file,
$NXBits::O_RDONLY));unless (defined ($FD)){(my $errorNumber=libnxh::NXGetError 
());(my $errorString=libnxh::NXGetErrorString ());Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x72\x65\x61\x64\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x04ab+ 2472-0x0e53));}if (
Common::NXFile::isExists ($tempFile)){unlink ($tempFile);}(my $openMode=((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND));(my $tempFD=main::nxopen
 ($tempFile,$openMode,$NXBits::UserReadWrite));unless (defined ($tempFD)){(my $errorNumber
=libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x27"
.$tempFile)."\x27\x20\x66\x6f\x72\x20\x77\x72\x69\x74\x65\x2e").((((
"\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".$errorString)."\x27\x2c\x20").
$errorNumber)."\x2e")));__unlock ();return ((0x03c5+ 780-0x06d1));}&try (sub{
while (main::nxreadLine ($FD,(\$_))){(my $line=$_);chomp ($line);(my ($keyUser,
$key)=split ( / / ,$line,(0x1f7b+ 909-0x2305)));($keyUser=main::urldecode (
$keyUser));if (($keyUser eq $username)){($flag_del=(0x12d0+ 274-0x13e1));}else{
Common::NXCore::nxwriteOrThrowException ($tempFD,$_);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tempFD);main::nxclose ($FD);__unlock ();
Logger::error (((
"\x55\x6e\x65\x78\x70\x65\x63\x65\x64\x20\x65\x72\x72\x6f\x72\x20\x77\x68\x69\x6c\x65\x20\x72\x65\x6d\x6f\x76\x69\x6e\x67\x20\x73\x61\x76\x65\x64\x20\x75\x73\x65\x72\x20\x74\x77\x6f\x20\x66\x61\x63\x74\x6f\x72\x20\x6b\x65\x79\x2e\x20"
.$error)."\x2e"));return ((0x12e5+ 4328-0x23cd));}));main::nxclose ($tempFD);
main::nxclose ($FD);if ((not (rename ($tempFile,$file)))){__unlock ();
Logger::error ((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempFile)."\x27\x20\x74\x6f\x20\x27").$file)."\x27\x2e\x20").$!));return (
(0x0fda+ 1962-0x1784));}(my ($errorName),$errorCode);if ((
Common::NXFile::setOwnerShipAndPermissionsForNX ($file,(\$errorName),(
\$errorCode))==(-(0x0366+ 1265-0x0856)))){__unlock ();Logger::error ((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x74\x20\x6f\x77\x6e\x65\x72\x73\x68\x69\x70\x20\x27\x6e\x78\x27\x20\x6f\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$file)."\x27\x20\x66\x6f\x72\x20\x75\x73\x65\x72\x20\x6e\x78\x2e\x20").
$errorName));return ((0x0c43+ 1565-0x1260));}__unlock ();return ($flag_del);}
package NXTwoFactorLoginDB;no warnings;my ($lockFD);sub __lock{(my $lockMode=(
shift (@_)||$NXBits::LOCK_EX));(my $lockFile=(NXPaths::getTwoFactorPublicKeys ()
."\x2e\x6c\x6f\x63\x6b"));(my $openMode=(($NXBits::O_CREAT+$NXBits::O_WRONLY)+
$NXBits::O_APPEND));($lockFD=main::nxopen ($lockFile,$openMode,
$NXBits::UserReadWrite));if ((not (defined ($lockFD)))){(my $error=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());
Logger::warning ((((
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x20\x27"
.$lockFile)."\x27\x2e").(((("\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27".
$errorString)."\x27\x2c\x20").$error)."\x2e")));return ((0x0006+ 3205-0x0c8b));}
main::nxflock ($lockFD,$lockMode);}sub __lockShared{return (__lock (
$NXBits::LOCK_SH));}sub __unlock{if (defined ($lockFD)){main::nxclose ($lockFD);
}($lockFD=undef);}return ((0x0ca7+ 2839-0x17bd));
